{% load i18n %}

<div class="sub-header">
    <h3>{% trans 'Authorisation' %}</h3>
</div>
{% if approval_item_number %}
    {% blocktrans count approval_item_number as num %}
    There is {{ num }} item pending authorisation.
    {% plural %}
    There are {{ num }} items pending authorisation.
    {% endblocktrans %}

    <div class="form-actions">
        <a href="{% url approval:order-line-approval-list %}" class="btn btn-primary">{% trans 'View approval list' %}</a>
    </div>

{% else %}
    <p>
        {% trans "There are no items pending authorisation." %}
    </p>
{% endif %}